@@ -661,6 +661,8 @@ fix_popover_menu_icons (GtkPopover *popover)
   menu_section_box = menu_section_children->data;
   menu_section_box_children = gtk_container_get_children (GTK_CONTAINER (menu_section_box));
 
+  gtk_style_context_add_class (gtk_widget_get_style_context (menu_section_box), "calendars-list");
+
   /**
    * Iterate through the GtkModelButtons inside the menu section box.
    */
@@ -684,6 +686,7 @@ fix_popover_menu_icons (GtkPopover *popover)
 
           if (g_type_is_a (G_OBJECT_TYPE (button_box_child), GTK_TYPE_IMAGE))
             {
+              gtk_style_context_add_class (gtk_widget_get_style_context (button_box_child), "calendar-color-image");
               gtk_widget_show (button_box_child);
               break;
             }
@@ -809,3 +812,35 @@ format_utc_offset (gint64 offset)
   else
     return g_strdup_printf ("%s%02i%02i", sign, hours, minutes);
 }
+
+gint
+get_alarm_trigger_minutes (GcalEvent          *event,
+                           ECalComponentAlarm *alarm)
+{
+  ECalComponentAlarmTrigger trigger;
+  GDateTime *alarm_dt;
+  gint diff;
+
+  e_cal_component_alarm_get_trigger (alarm, &trigger);
+
+  /*
+   * We only support alarms relative to the start date, and solely
+   * ignore whetever different it may be.
+   */
+  if (trigger.type != E_CAL_COMPONENT_ALARM_TRIGGER_RELATIVE_START)
+    return -1;
+
+  alarm_dt = g_date_time_add_full (gcal_event_get_date_start (event),
+                                   0,
+                                   0,
+                                   - (trigger.u.rel_duration.days + trigger.u.rel_duration.weeks * 7),
+                                   - trigger.u.rel_duration.hours,
+                                   - trigger.u.rel_duration.minutes,
+                                   - trigger.u.rel_duration.seconds);
+
+  diff = g_date_time_difference (gcal_event_get_date_start (event), alarm_dt) / G_TIME_SPAN_MINUTE;
+
+  g_clear_pointer (&alarm_dt, g_date_time_unref);
+
+  return diff;
+}
